@@ -81,6 +81,11 @@ class Watch(object):
             return data
 
         if 'object' not in js or 'type' not in js:
+            # raise error with code if set
+            if 'code' in js:
+                reason = "{}: {}".format(js.get('reason'), js.get('message'))
+                raise client.exceptions.ApiException(status=js['code'], reason=reason)
+
             raise Exception(("Malformed JSON response, the 'object' and/or "
                              "'type' field is missing. JSON: {}").format(js))
         # Make a copy of the original object and save it under the
@@ -93,7 +98,9 @@ class Watch(object):
         # not send a conventional ADDED/DELETED/... event but an error. Turn
         # this error into a Python exception to save the user the hassle.
         if js['type'].lower() == 'error':
-            return js
+            obj = js['raw_object']
+            reason = "{}: {}".format(obj['reason'], obj['message'])
+            raise client.exceptions.ApiException(status=obj['code'], reason=reason)
 
         # If possible, compile the JSON response into a Python native response
         # type, eg `V1Namespace` or `V1Pod`,`ExtensionsV1beta1Deployment`, ...
